[![PyPI version](https://badge.fury.io/py/nqviz.svg)](https://badge.fury.io/py/nqviz)
[![GitHub issues](https://img.shields.io/github/issues/jhan15/nqviz)](https://github.com/jhan15/nqviz/issues)
[![GitHub license](https://img.shields.io/github/license/jhan15/nqviz)](https://github.com/jhan15/nqviz/blob/master/license.txt)
# nqviz 

nqviz is a tool to visualize the n-queen problem. Random column pick is used.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install nqviz.

```bash
pip install nqviz
```

## Usage

```python
from nqviz import Nqueen

Nqueen(6) # run n-queen on a 6*6 chessboard
```

#### 6-queen

<img src="https://user-images.githubusercontent.com/62132206/120168297-0040cc80-c1ff-11eb-9a7a-de5e1568fc70.gif" width="300">

## License
[MIT](https://choosealicense.com/licenses/mit/)
